@@ -2,15 +2,27 @@
 
 __docformat__ = 'restructuredtext'
 
+__version__ = '0.3'
+
+import model
 import likelihoods
 import generate
 import utils
+import sandbox
 
 from model import *
-from utils import plot_posteriors, plot_post_pred
 
 import wfpt
-import wfpt_full
+try:
+    import wfpt_switch
+except:
+    pass
+
+
+try:
+    import lba
+except ImportError:
+    pass
 
 from kabuki.utils import load_csv, save_csv
 
